@@ -24,6 +24,18 @@ DATA_TYPES = {
 }
 COHORT_SUPPORTED_DATATYPES = ["Raw Counts Transcriptomics"]
 COHORT_SUPPORTED_DATASOURCES = ["GEO"]
+COHORT_LIST_COLS_TO_DROP = [
+    "sample_characteristics",
+    "timestamp_",
+    "curated_control",
+    "curated_cohort_id",
+    "curated_cohort_name",
+    "curated_is_control",
+    "curated_max_age",
+    "curated_min_age",
+    "curated_age_unit",
+]
+MA_SUPPORTED_REPO = ["geo_transcriptomics_omixatlas"]
 
 # validation flow files url github
 VALIDATION_FLOW_FILES_URL = (
@@ -122,6 +134,8 @@ INGESTION_FILES_PATH_DIR_NAMES = ["metadata", "data"]
 
 SCHEMA_CONFIG_KEY_NAMES = ["source", "datatype"]
 
+VALIDATION_SCOPE_CONSTANTS = ["basic", "advanced"]
+
 SCHEMA_CONFIG_FORMAT = {"source": "<source_name", "datatype": "<datatype_name>"}
 
 FORMATTED_METADATA = {"id": "", "type": "", "attributes": {}}
@@ -563,6 +577,8 @@ MACHINES_FOR_JOBS = (
 DATA_LOG_MODES = ["latest", "all"]
 MIXPANEL_KEY = "91fa77fcf07f7b672b5c5c6c09d8a14c"
 
+PROD_ENV_NAME = "polly"
+
 POLLY_PYTHON_PYPI_URL = "https://pypi.python.org/pypi/polly-python/json"
 ERROR_MSG_GET_METADATA = "Argument 'table_name' not valid, please query 'SHOW TABLES IN repo_name' \
 using query_metadata function and pick the appropriate table name you want the metadata \
@@ -577,3 +593,19 @@ TABLE_NAME_SAMPLE_LEVEL_INDEX_MAP = {
 POLLY_PYTHON_LATEST_VERSION_FILE = (
     "https://elucidatainc.github.io/PublicAssets/polly_python_latest_version.txt"
 )
+
+QUERY_MAX_RECORD_SIZE = 20000
+# this control lever is for testing as data is less on testpolly
+DEFAULT_PAGE_SIZE_LIST_FILES = 2600
+
+DEFAULT_PAGE_SIZE_LIST_FILES_KEY_NAME = "default_page_size_list_files"
+
+PAGE_REDUCTION_PERCENTAGE_LIST_FILES = 20
+
+PAGE_REDUCTION_PERCENTAGE_LIST_FILES_KEY_NAME = "page_reduction_percentage_list_files"
+
+LIST_FILE_API_CONTROL_LEVER_LINK = (
+    "https://elucidatainc.github.io/PublicAssets/list_files_api_control_lever/"
+    + "list_files_control_lever.json"
+)
+QUERY_API_V2 = "v2"
