@@ -159,6 +159,11 @@ class TechnicalFaultException(Exception):
 the arguments passed and try again. Contact Polly Support in case of repeated failure."
 
 
+class RequestFailureException(Exception):
+    def __str__(self):
+        return "Sorry, we're unable to fetch the metadata now. Please contact polly.support@elucidata.io"
+
+
 class InvalidDatatypeException(Exception):
     def __str__(self):
         return "Single Cell Datatype is not incorporated. Please contact Polly Support."
